@@ -13,7 +13,7 @@ def throws(f,args:tuple=tuple())->None:
 class nThread:
 	def __init__(
 		self,
-		n:int=20,
+		n:int=0,
 		waits:int=0,
 		f=None,
 		args:list=None,
@@ -21,19 +21,21 @@ class nThread:
 	):
 		self.__ed=False
 		self.__q=list()
-		self.__n=n
+		self.__n=n if n else (len(args) if fast else 16)
 		self.__waits=waits
 		self.__mian=throws(self.__f)
 		if fast:
 			self.ths(f,args)
 			self.join()
 
-
 	def __repr__(self):
-		return '<class qThread with '+str(self.__n)+' threads and '+str(self.__waits)+' seconds wait time>'
+		return '<class nThread with '+str(self.__n)+' threads and '+str(self.__waits)+' seconds wait time>'
 
-	# def __del__(self):
-	# 	print('del this qThread, but '+str(self.__n)+'(or less) threads are running...')
+	def __str__(self):
+		return '<class nThread with '+str(self.__n)+' threads and '+str(self.__waits)+' seconds wait time>'
+
+	def __del__(self):
+		print('del this nThread, but '+str(self.__n)+'(or less) threads are running...')
 
 	def __f(self):
 		_l=list()
@@ -65,4 +67,4 @@ class nThread:
 	def join(self):
 		self.__ed=True
 		self.__mian.join()
-		self.__ed=False
+		self.__ed=False
\ No newline at end of file
